// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

////////////////////////////////////////////////////////////////////////////////
////////             BEGIN MANIPULATION FOR HOFFMAN CHAPTER 2 DATA        ///////
////////               CHANGE "filesave" to your directory                ///////
////////////////////////////////////////////////////////////////////////////////

// Defining global variable for file location to be replaced in code below
   global filesave "C:\Dropbox\21SP_PSQF6242\PSQF6242_Example6"
// Using UIowa virtual desktop instead
   //global filesave "\\Client\C:\Dropbox\21SP_PSQF6242\PSQF6242_Example6"

// Import chapter 2 data into temporary file and center predictors
   use "$filesave\STATA_Chapter2.dta", clear // Has converted all variables to lower-case
   
// Center quantitative predictors
   gen age85 = age - 85
   gen grip9 = grip - 9
// Create age*grip interaction for semi-partial eta2
   gen agegrip = age85*grip9

// Create dummy-coded binary predictors for dementia groups
   gen demnf=.
   gen demnc=.
// Demgroup = none   
   replace demnf=0 if demgroup==1
   replace demnc=0 if demgroup==1
// Demgroup = future 
   replace demnf=1 if demgroup==2
   replace demnc=0 if demgroup==2
// Demgroup = current
   replace demnf=0 if demgroup==3
   replace demnc=1 if demgroup==3
   
// Label all variables
   label variable age85     "age85: Age in Years (0=85)"
   label variable grip9     "grip9: Grip Strength in Pounds (0=9)"
   label variable sexmw     "sexmw: Sex (0=Men, 1=Women)"
   label variable demnf     "demnf: Dementia Contrast for None=0 vs Future=1"
   label variable demnc     "demnc: Dementia Contrast for None=0 vs Current=1"
   label variable cognition "cognition: Cognition Outcome"
   label variable demgroup  "demgroup: Dementia Group 1N 2F 3C"

// Select cases complete on variables
   egen nmiss=rowmiss(cognition age grip sexmw demgroup)
   drop if nmiss>0

    
////////////////////////////////////////////////////////////////////////////////
////////                  BEGIN GENERAL LINEAR MODELS                     //////
////////////////////////////////////////////////////////////////////////////////

// Save results to separate file
   log using $filesave\Example6_STATA_Output.log, replace

display "STATA Combined Main Effects Only Model Predicting Cognition"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc, level(95)
   // We are ignoring the effects we would normally request for dementia for now
   // Pred cognition outcomes holding sexMW=men, demNF=none, and demNC=none
   // one margins replaces 9 ESTIMATEs in SAS; vsquish compresses output empty lines
   // predictor=(from(by)to), c.=quantitative predictor 
   margins, at(c.age85=(-5(5)5) c.grip9=(-3(3)3) c.sexmw=0 c.demnf=0 c.demnc=0) vsquish
   // Get plot of predicted outcomes and save
   marginsplot, xdimension(grip9) name(predicted_means, replace) 
   

display "STATA: GLM adding 2 Interactions (Sex by Age and Sex by Grip"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc  /// line continuer
                  c.sexmw#c.age85 c.sexmw#c.grip9, level(95)
   lincom c.demnf*-1 + c.demnc*1 // Mean Diff: Future vs. Current = B5-B4
   test (c.demnf=0)(c.demnc=0)   // DFnum=2 F-test for Demgroup
   test (c.sexmw#c.age85=0)(c.sexmw#c.grip9=0) // DFnum=2 F-test for new interactions
// Simple slopes of age by sex   
   lincom c.age85*1 + c.sexmw#c.age85*0  // Age Slope for Men
   lincom c.age85*1 + c.sexmw#c.age85*1  // Age Slope for Women
// Simple slopes of grip by sex   
   lincom c.grip9*1 + c.sexmw#c.grip9*0  // Grip Slope for Men
   lincom c.grip9*1 + c.sexmw#c.grip9*1  // Grip Slope for Women
// Get predicted outcomes for each combination of (from(by)to)
   margins, at(c.age85=(-5(10)5) c.grip9=(-3(6)3) c.sexmw=(0(1)1) c.demnf=0 c.demnc=0) vsquish
   marginsplot, xdimension(age85) bydimension(grip9)  // Plot pred outcomes by age 
   marginsplot, xdimension(grip9) bydimension(age85)  // Plot pred outcomes by grip 

// Stata: calculate semipartial eta2 for 2 new interactions using SS from reduced model
display "STATA Reduced Model to Get SS for demnf and demnc (not included)"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (18529.397-18385.9793)/66296.5382 // sr2 for sex*age, sex*grip = .00216328

   
display "STATA Eq 2.9: Adding Age by Grip Interaction"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc c.age85#c.grip9, level(95)
  lincom c.demnf*-1 + c.demnc*1 // Mean Diff: Future vs. Current = B5-B4
  test (c.demnf=0)(c.demnc=0)   // DFnum=2 F-test for Demgroup
  test (c.age85=0)(c.grip9=0) (c.age85#c.grip9=0) // DFnum=3 F-test for age, grip, age*grip
  estat vce  // Aymptotic covariance matrix of fixed effects for regions
// dydx in margins provides simple slopes for that variable by (from(by)to) moderator
   margins, at(c.grip9=(-3(3)3)) dydx(c.age85) vsquish // Age Slope per Grip
   lincom c.age85*1 + c.age85#c.grip9*-3  // Age Slope at Grip =  6
   lincom c.age85*1 + c.age85#c.grip9*0   // Age Slope at Grip =  9
   lincom c.age85*1 + c.age85#c.grip9*3   // Age Slope at Grip = 12
// dydx in margins provides simple slopes for that variable by (from(by)to) moderator
   margins, at(c.age85=(-5(5)5)) dydx(c.grip9) vsquish // Grip Slope per Age
   lincom c.grip9*1 + c.age85#c.grip9*-5  // Grip Slope at Age = 80
   lincom c.grip9*1 + c.age85#c.grip9*0   // Grip Slope at Age = 85
   lincom c.grip9*1 + c.age85#c.grip9*5   // Grip Slope at Age = 90
// one margins replaces 8 ESTIMATEs in SAS; vsquish compresses output empty lines
   // predictor=(from(by)to), c.=quantitative predictor 
   margins, at(c.age85=(-5(5)5) c.grip9=(-3(3)3) c.sexmw=0 c.demnf=0 c.demnc=0) vsquish
   marginsplot, xdimension(age85)  // Plot pred outcomes by age 
   marginsplot, xdimension(grip9)  // Plot pred outcomes by grip 
   
   
display "STATA Eq 2.9: Full Model with Age by Grip Interaction (repeated)"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc c.age85#c.grip9, level(95)
      
// Get semipartial eta2 for non-conditional terms
pcorr cognition age85 grip9 sexmw demnf demnc agegrip 

// Stata: calculate semipartial eta2 for demgroup using SS from reduced model
display "STATA Reduced Model to Get SS for demnf and demnc (not included)"
regress cognition c.age85 c.grip9 c.sexmw c.age85#c.grip9, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (19185.0411-7437.43517)/66296.5382 // sr2 for demgroup = .17719788

// Stata: calculate semipartial eta2 for age, grip, age*agrip using SS from reduced model
display "STATA Reduced Model to Get SS for age, grip, age*agrip (not included)"
regress cognition c.sexmw c.demnf c.demnc, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (19185.0411-15385.1841)/66296.5382 // sr2 for age,grip,age*grip = .05731607


display "STATA Eq 2.9: Age by Grip Interaction adding VCE for Regions"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc c.age85#c.grip9, level(95)
  estat vce  // Aymptotic covariance matrix of fixed effects for regions

   
// Close log
log close

